#
# spec file for package spread-sheet-widget
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2017,2020,2024 <opensuse.lietuviu.kalba@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         libname libspread-sheet-widget0
Name:           spread-sheet-widget
Version:        0.10
Release:        1.3
Summary:        GNU Spread Sheet Widget library for Gtk+
License:        GPL-3.0-or-later
Group:          Development/Libraries/X11
URL:            https://www.gnu.org/software/ssw/
Source0:        https://alpha.gnu.org/gnu/ssw/%{name}-%{version}.tar.gz
# *sig. can be converted into *.asc by:
# gpg --enarmor spread-sheet-widget-*.tar.gz.sig
Source1:        https://alpha.gnu.org/gnu/ssw/%{name}-%{version}.tar.gz.sig
Source2:        %{name}.keyring
BuildRequires:  gtk3-devel >= 3.18.0

%description
GNU Spread Sheet Widget is a library for Gtk+ which provides a widget for
viewing and manipulating 2-dimensional tabular data in a manner similar
to many popular spread sheet programs.

The design follows the model-view-controller paradigm and is of complexity O(1)
in both time and space. This means that it is efficient and fast even for very
large data.

Features commonly found in graphical user interfaces such as cut and paste,
drag and drop and row/column labelling are also included.

%package -n %{libname}
Summary:        GNU Spread Sheet Widget library for Gtk+
Group:          System/Libraries

%description -n %{libname}
GNU Spread Sheet Widget is a library for Gtk+ which provides a widget for
viewing and manipulating 2-dimensional tabular data in a manner similar to many
popular spread sheet programs.

The design follows the model-view-controller paradigm and is of complexity O(1)
in both time and space. This means that it is efficient and fast even for very
large data.

Features commonly found in graphical user interfaces such as cut and paste,
drag and drop and row/column labelling are also included.

%package devel
Summary:        Header files for GNU Gtk+ Spread Sheet Widget library
Group:          Development/Libraries/X11
Requires:       %{libname} = %{version}

%description devel
GNU Spread Sheet Widget is a library for Gtk+ which provides a widget
for viewing and manipulating 2-dimensional tabular data in a manner
similar to many popular spread sheet programs.

This subpackage contains the header files for the library.

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags} 

%install
%make_install
find %{buildroot}%{_libdir} -name "*.la" -delete
[ -f %{buildroot}/usr/share/info/dir ] && rm %{buildroot}/usr/share/info/dir

%post -n %{libname} 
/sbin/ldconfig
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%preun -n %{libname}
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%{_libdir}/lib%{name}.so.0*
%{_infodir}/%{name}.info*

%files devel
%{_includedir}/ssw-axis-model.h
%{_includedir}/ssw-sheet-axis.h
%{_includedir}/ssw-sheet.h
%{_includedir}/ssw-virtual-model.h
%{_libdir}/lib%{name}.so
%attr(0644,root,root) %{_libdir}/pkgconfig/%{name}.pc

%changelog
* Tue Mar 12 2024 opensuse.lietuviu.kalba@gmail.com
- Update to version 0.10.
- Changes between version 0.9 and 0.10:
  * Update obsolete macro in configure.ac
  * Correctly draw selection when in RTL locales
  * Arrange for make dist to be reproducible
- Changes between version 0.8 and 0.9:
  * Use a fallback algorithm if scrolling to a row/column fails
* Tue May 11 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.8:
  * Just build system related changes
* Sat Oct 10 2020 opensuse.lietuviu.kalba@gmail.com
- Update to 0.7:
  - Added library dependencies for GTK and GLIB.
  - Fixed a few compiler warnings.
  - Avoid problem if size allocating when not realised.
  - Add calls to gtk_widget_has_set_window as appropriate.
  - Improve axis.
  - xpaned: Add missing realize / unrealize calls.
  - Update AUTHORS
  - Remove file cl-t.
* Wed Sep 23 2020 opensuse.lietuviu.kalba@gmail.com
- Provide URL to upstream SIG file, instead of non-existing ASC.
* Tue Sep 22 2020 Lars Vogdt <lars@linux-schulserver.de>
- fix download URLs for sources
* Wed Jul 29 2020 opensuse.lietuviu.kalba@gmail.com
- Update to 0.6
  - Avoid compiler warning about signedness.
  - Add some comments and some ssw_ prefixes.
  - Don't set input-hints for Gtk+ versions which don't have it.
* Sat Jul 18 2020 opensuse.lietuviu.kalba@gmail.com
- Update to 0.5:
  - Fix copy/paste/cut if an editable is focused - #57274.
  - Fix broken interaction between visibility and split property.
  - Fix broken "editable" property.
  - Enter the editable's data when a button is pressed.
  - Update editable when forward conversion function is changed.
  - Redraw when data is changed.
  - New property: selection.
  - Don't show the "Insert Emoji" menuitem in the entry's popup menu.
  - Clip source: Do not print final newline.
  - Other changes.
* Sat Jul  4 2020 opensuse.lietuviu.kalba@gmail.com
- Added keyring and added SOURCE.asc
- Update to 0.4:
  - Fix crash when pasting from primary
  - Fix bug where when there was no active cell, the place where it
    would have been was blanked.
  - Added check to out-of-sight processing (bug #55357) in ssw-sheet-axis.c
  - Removed force_update callback to prevent stall (#55357)
  - Changed key-press-event generation to avoid warnings.
  - Add push/pop functions for cursor
* Sun Jan 13 2019 Jan Engelhardt <jengelh@inai.de>
- Replace boilerplate package description.
* Mon Nov 12 2018 opensuse.lietuviu.kalba@gmail.com
- Fix build for Fedora.
* Wed Nov  7 2018 lars@linux-schulserver.de
- Update to 0.3:
  + Fix bug where when there was no active cell, the place where it
    would have been was blanked.
  + Update NEWS
  + Fix crash when pasting from primary
  + SswXpaned: Remove unused code
- do not package static libs
- run install-info macros
- removed Fix_crash_when_pasting_from_primary.patch (upstream)
* Thu Nov 23 2017 opensuse.lietuviu.kalba@gmail.com
- spread-sheet-widget 0.2 – initial RPM package for openSUSE.
